===============================
DBaaS ACLAPI
===============================

.. image:: https://badge.fury.io/py/backstage-oauth2.png
    :target: http://badge.fury.io/py/backstage-oauth2

.. image:: https://travis-ci.org/felippemr/backstage-oauth2.png?branch=master
        :target: https://travis-ci.org/felippemr/backstage-oauth2

.. image:: https://pypip.in/d/backstage-oauth2/badge.png
        :target: https://pypi.python.org/pypi/backstage-oauth2


ACL API integration for DBaaS

* Free software: BSD license
* Documentation: https://backstage-oauth2.readthedocs.org.

Features
--------

* TODO
